/**
 * Toggles business hour sections
 * 
 * Disables business hour inputs on checkbox click.
 * References Business Settings > Business Hours Tab.
 *
 * @link https://timeslotplugins.com
 *
 * @package Time Slot
 * @since 1.0.0
 * 
 */

jQuery(function() {

	// TimePicker
	jQuery('.ts-business-hours.timepicker').timepicker({
		'timeFormat': tshours.timeformat
	});

	// Holiday DatePicker
	jQuery('.ts-holiday-date').each(function() {

		jQuery(this).datepicker({
			altField: jQuery(this).next('.ts-format-holiday-date'),
			altFormat: 'yy-mm-dd',
			beforeShow: function() {
				jQuery('#ui-datepicker-div').addClass('ts-datepicker');
			},
			dateFormat: tshours.dateformat,
			firstDay: tshours.startofweek,
			minDate: 0,
			nextText: '',
			prevText: '',
			showAnim: '',
		})

	});

	// Toggles disabled property on time inputs
	function checkisclosed(){

		const closedThis = jQuery(this);
		const closedName = jQuery(this).attr('name');
		const closedNameString = closedName.substr(0,closedName.indexOf('day'));
		const businessHours = jQuery('.ts-business-hours');

		businessHours.each(function(){

			const businessHoursName = jQuery(this).attr('name');
			const businessHoursNameString = businessHoursName.substr(0,businessHoursName.indexOf('day'));

			if (businessHoursNameString === closedNameString){
				if (closedThis.is(':checked')) {
					jQuery(this).prop('disabled',true).prop('value','');
					if(jQuery(this).hasClass('ts-error')){
						jQuery(this).removeClass('ts-error').removeAttr('aria-invalid');
						jQuery(this).prev('.ts-error').remove();
					}
				}
				else {
					jQuery(this).prop('disabled',false);
				}
			}

		})

	}

	const closedcheckbox = jQuery('.ts-closed');
	closedcheckbox.each(checkisclosed);
	closedcheckbox.on('click',(checkisclosed));

	//Trim weekday name strings on mobile width
	jQuery('.ts-hours-wrapper .ts-day-label').each(function(){

		const maxWidth480 = window.matchMedia("(max-width: 480px)");
		const dayLabel = jQuery(this);
		const fullLengthDay = jQuery(this).text();
		const shortLengthDay = jQuery(this).text().substring(0, 3);

		function check480(maxWidth480){
			if (maxWidth480.matches) {
				dayLabel.text(shortLengthDay);
			}
			else {
				dayLabel.text(fullLengthDay);
			}
		}
		
		check480(maxWidth480);

		maxWidth480.addEventListener('change', function() {
			check480(maxWidth480);
		});

	})

})