<?php
/**
 * Creates business settings menu page and tabs
 *
 * @link https://timeslotplugins.com
 *
 * @package Time Slot
 * @since 1.0.0
 * 
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
	exit;
}

// Adds business settings to admin menu
add_action('admin_menu', 'tslot_business_page');

function tslot_business_page() {
	add_submenu_page(
		'timeslot',
		__('Business Settings', 'timeslot'),
		__('Business Settings', 'timeslot'),
		'manage_options',
		'timeslot-business-settings',
		'tslot_business_html'
	);
}

// Includes settings pages
include_once(TIMESLOT_PATH . 'admin/pages/tables/staff.php');
include_once(TIMESLOT_PATH . 'admin/pages/tables/services.php');
include_once(TIMESLOT_PATH . 'admin/pages/tables/data-delete.php');
include_once(TIMESLOT_PATH . 'admin/pages/tables/build-table.php');
include_once(TIMESLOT_PATH . 'admin/pages/settings/email.php');
include_once(TIMESLOT_PATH . 'admin/pages/settings/company.php');
include_once(TIMESLOT_PATH . 'admin/pages/settings/hours.php');

// Displays tabs, settings fields and sections
function tslot_business_html() {

	if (!current_user_can('manage_options')) {
		return;
	}

	include_once(TIMESLOT_PATH . 'admin/header.php');
	$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'services';

	$nav = array(
		'services',
		'staff',
		'email',
		'company',
		'business-hours',
	);

	?>

	<nav class='ts-nav nav-tab-wrapper' aria-label='<?php esc_attr_e('Business Settings', 'timeslot');?>'>
		<ul>
		<?php 
			foreach($nav as $item){

				$class = $active_tab === $item ? 'nav-tab-active' : '';
				$label = __(ucwords(str_replace('-',' ',$item)), 'timeslot');
				$url = add_query_arg( array(
					'page' => 'timeslot-business-settings',
					'tab' => $item,
				));

				?>
				<li>
					<a href='<?php echo esc_url($url); ?>' class='nav-tab <?php esc_attr_e($class); ?>'><?php esc_html_e($label);?></a>
				</li>
				<?php

			}
			?>
		</ul>
	</nav>

	<?php
	switch ($active_tab) {
		case 'services':
			tslot_services_tab_init();
			break;
		case 'staff':
			tslot_staff_tab_init();
			break;
		case 'email':
		case 'company':
		case 'business-hours':
			?>
			<form method='post' action='<?php echo esc_url('options.php'); ?>' id='<?php esc_attr_e('ts-' . $active_tab . '-form');?>' class='ts-settings-form ts-load'>
				<?php
				if ($active_tab == 'business-hours'){
					settings_fields('timeslot-business-hours-group');
					tslot_do_settings_sections('timeslot-business-hours-tab');
				}
				else{
					settings_fields('timeslot-'. $active_tab .'-tab');
					do_settings_sections('timeslot-'. $active_tab .'-tab');
				}
				submit_button(__('Save Changes', 'timeslot'), 'ts-btn');
				?>
			</form>
			<?php
			break;
		default:
			tslot_services_tab_init();
			break;
	}
	?>

	<p class='ts-success-msg' role='alert'>
		<?php esc_html_e('Settings Saved', 'timeslot')?>
	</p>

	<?php
}