<?php
/**
 * Creates general settings menu page and tabs
 *
 * @link https://timeslotplugins.com
 *
 * @package Time Slot
 * @since 1.0.0
 * 
 */

// Exit if accessed directly
if (!defined('ABSPATH')){
	exit;
}

// Adds general settings to admin menu
add_action( 'admin_menu', 'tslot_settings_page' );

function tslot_settings_page() {
	add_submenu_page(
		'timeslot',
		__('General Settings', 'timeslot'),
		__('General Settings', 'timeslot'),
		'manage_options',
		'timeslot-general-settings',
		'tslot_general_html'
	);
}

// Includes settings pages
include_once( TIMESLOT_PATH . 'admin/pages/settings/general.php' );
include_once( TIMESLOT_PATH . 'admin/pages/settings/appearance.php' );
include_once( TIMESLOT_PATH . 'admin/pages/settings/payment.php' );
include_once( TIMESLOT_PATH . 'admin/pages/settings/import-export.php' );

// Displays tabs, settings fields and sections
function tslot_general_html() {

	if (!current_user_can('manage_options')){
		return;
	}

	include_once( TIMESLOT_PATH . 'admin/header.php' );
	$active_tab = isset($_GET['tab']) ? sanitize_text_field($_GET['tab']) : 'general';

	$nav = array(
		'general' => __('General', 'timeslot'),
		'payment-methods' => __('Payment Methods', 'timeslot'),
		'appearance' => __('Appearance', 'timeslot'),
		'import-export' => __('Import/Export', 'timeslot'),
	);

	?>

	<nav class='ts-nav nav-tab-wrapper' aria-label='<?php esc_attr_e('Time Slot Settings', 'timeslot');?>'>
		<ul>
			<?php 
			foreach($nav as $link => $title){

				$class = $active_tab === $link ? 'nav-tab-active' : '';
				$url = add_query_arg( array(
					'page' => 'timeslot-general-settings',
					'tab' => $link,
				));

				?>
				<li>
					<a href='<?php echo esc_url($url); ?>' class='nav-tab <?php esc_attr_e($class); ?>'><?php esc_html_e($title); ?></a>
				</li>
				<?php

			}
			?>
		</ul>
	</nav>
	<?php

	if ($active_tab == 'import-export'){
		tslot_import_export_tab_init();
	}

	else {

		?>
		<form method='post' action='<?php echo esc_url('options.php'); ?>' id='<?php esc_attr_e('ts-' . $active_tab . '-form');?>' class='ts-settings-form ts-load'>
			<?php
			settings_fields( 'timeslot-' . $active_tab . '-tab' );
			do_settings_sections( 'timeslot-' . $active_tab . '-tab' );
			submit_button(__('Save Changes', 'timeslot'), 'ts-btn');
			?>
		</form>
		<?php
	}

	?>
	<p class='ts-success-msg' role='alert'>
		<?php esc_html_e('Settings Saved', 'timeslot')?>
	</p>
	<?php

}