<?php
/**
 * Disables dates in datepicker
 *
 * Controls closed business days and
 * holidays in frontend form datepicker
 *
 * @link https://timeslotplugins.com
 *
 * @package Time Slot
 * @since 1.0.0
 * 
 */


add_action( 'rest_api_init', function () {
	register_rest_route( 'timeslot/v1', '/ts-business-hours/', array(
			'methods' => WP_REST_Server::READABLE,
			'callback' => 'tslot_get_business_hours',
			'permission_callback' => '__return_true',
	));
});


function tslot_get_business_hours($request){

	global $wpdb,
	$chosen_staff,
	$chosen_service,
	$hours_wp_option,
	$to_datepicker,
	$timezone,
	$weekdays,
	$ts_services_table,
	$ts_appt_table,
	$ts_staff_services_table,
	$approved_i18n,
	$visible_i18n;

	$chosen_staff = $request['staff'];
	$chosen_service = $request['service'];

	$ts_services_table = $wpdb->prefix . 'ts_services';
	$ts_appt_table = $wpdb->prefix . 'ts_appointments';
	$ts_staff_services_table = $wpdb->prefix . 'ts_staff_services';

	$hours_wp_option = get_option('timeslot-business-hours');
	$timezone = get_option('timezone_string');

	$weekdays = array('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday');
	$to_datepicker = array();

	// I18n strings
	$i18n_strings = new TimeSlot\MultilangStrings();
	$visible_i18n = $i18n_strings -> visible_string;
	$approved_i18n = $i18n_strings -> approved_string;


	tslot_staff_and_business_days();

	tslot_weekdays();

	tslot_holidays();

	return $to_datepicker;

}


function tslot_staff_and_business_days(){

	// Disable business and staff days off for 1 year
	global $wpdb,
	$to_datepicker,
	$weekdays,
	$hours_wp_option,
	$chosen_staff,
	$chosen_service,
	$ts_staff_services_table,
	$visible_i18n;

	$ts_staff_table = $wpdb->prefix . 'ts_staff';

	$first_of_month = new DateTime('first day of this month');
	$one_year_ahead = new DateTime('first day of this month +1 year');
	$one_day_interval = new DateInterval('P1D');
	$days_off_range = new DatePeriod($first_of_month, $one_day_interval, $one_year_ahead);

	// Get staff days off
	switch ($chosen_staff) {
		case '':
			break;
		case __('Any Staff Member', 'timeslot'):
			$available_staff = 
				$wpdb->get_results(
				$wpdb->prepare(
					"SELECT 
					{$ts_staff_table}.daysoff
					FROM {$ts_staff_table}, {$ts_staff_services_table} 
					WHERE {$ts_staff_services_table}.service_title = %s 
					AND {$ts_staff_services_table}.staff_id = {$ts_staff_table}.staff_id 
					AND {$ts_staff_table}.visibility = %s", 
					$chosen_service, $visible_i18n
			));

			$any_staff_days_off = array_column($available_staff, 'daysoff');
			$staff_dayoff_count = count($any_staff_days_off);
			$staff_days_off = array();
			$duplicate_days = array();
			
			foreach($any_staff_days_off as $any_staff_day_off){
				$staff_days_off = array_merge($staff_days_off, explode(",", $any_staff_day_off));
			}

			$duplicates = array_count_values($staff_days_off);

			foreach($duplicates as $day => $count){
				if ($count <= 1){
					continue;
				}
				if ($count >= $staff_dayoff_count){
					$duplicate_days[] = $day;
				}
			}

			$staff_days_off = $duplicate_days;

			break;
		default:
			$staff_days =
				$wpdb->get_var(
				$wpdb->prepare(
					"SELECT daysoff 
					FROM {$ts_staff_table} 
					WHERE staff_name = %s",
					$chosen_staff
			));

			$staff_days_off = explode(',', $staff_days ?? '');
			break;
	}

	foreach($days_off_range as $range) {

		$first_of_month->add(new DateInterval('P1D'));
		$day = $first_of_month->format('Y-m-d');
		$day_unix = $first_of_month->format('U');
		$day_of_week = $first_of_month->format('l');

		// Disable business days off
		foreach($weekdays as $weekday){
			$weekday_closed = isset($hours_wp_option[strtolower($weekday)]['closed']) ? $hours_wp_option[strtolower($weekday)]['closed'] : null;

			if (!isset($weekday_closed)){
				continue;
			}
			if ($day_of_week !== $weekday && $weekday_closed !== 1) {
				continue;
			}
			if (!in_array($day, $to_datepicker)){
				$to_datepicker[]= $day;
			}
		}

		// Disable staff days off
		if (!isset($staff_days_off) || !$staff_days_off){
			continue;
		}

		foreach($staff_days_off as $staff_day_off){
			if ($staff_day_off !== $day_of_week){
				continue;
			}
			if (!in_array($day, $to_datepicker)){
				$to_datepicker[]= $day;
			}
		}

	}
}


function tslot_weekdays(){

	global $weekdays,
	$chosen_service,
	$chosen_staff,
	$hours_wp_option,
	$num_appts;

	// Disable Filled Appointment Dates in DatePicker
	foreach($weekdays as $weekday){

		if (empty($chosen_service) || empty($chosen_staff)){
			continue;
		}

		tslot_business_hours($weekday);

		tslot_appt_totals();

		tslot_after_close_today($weekday);

		tslot_cutoff_date($weekday);

		if ($num_appts == 0) {
			continue;
		}

		tslot_staff_booked_for_service($weekday);

		tslot_service_fully_booked($weekday);

		tslot_fifteen_minute_intervals($weekday);

	}
}


function tslot_holidays(){

	global $timezone,
	$to_datepicker;

	$holiday_wp_option = get_option('timeslot-holidays');

	if (empty($holiday_wp_option)){
		return;
	}

	$saved_holiday = $holiday_wp_option['closed'];
	$first_of_month = new DateTime('first day of this month');
	$five_years_ahead = new DateTime('first day of this month +5 years');
	$one_year_interval = new DateInterval('P1Y');
	$holiday_range = new DatePeriod($first_of_month, $one_year_interval, $five_years_ahead);
	$now = new DateTime('now', new DateTimeZone($timezone));
	$yr = 0;

	foreach($saved_holiday as $holiday){

		$holiday_date = $holiday['date'];

		if (empty($holiday_date)){
			continue;
		}

		$new_holiday = new DateTime($holiday_date);

		if ($new_holiday > $now){
			if (!in_array($holiday_date, $to_datepicker)){
				$to_datepicker[]= $holiday_date;
			}
		}

		if (!isset($holiday['annual']) || $holiday['annual'] !== 'annual'){
			continue;
		}

		foreach($holiday_range as $range) {
			$future_holiday = date('Y-m-d',strtotime('+'.$yr.' year',strtotime($holiday_date)));
			if (!in_array($future_holiday, $to_datepicker)){
				$to_datepicker[]= $future_holiday;
			}
			$yr++;
		}

	}
}


function tslot_business_hours($weekday){

	global $start_time,
	$end_time,
	$timezone,
	$hours_wp_option,
	$business_closed_unix;

	$weekday_lower = strtolower($weekday);
	$day_start = isset($hours_wp_option[$weekday_lower]['start-hour']) ? $hours_wp_option[$weekday_lower]['start-hour'] : null;
	$day_end = isset($hours_wp_option[$weekday_lower]['end-hour']) ? $hours_wp_option[$weekday_lower]['end-hour'] : null;

	if (!isset($day_start) || !isset($day_end)){
		$end_time = 0;
		$start_time = 0;
		$business_closed_unix = 0;
		return;
	}

	$business_closed = new DateTime($day_end, new DateTimeZone($timezone));
	$business_closed_unix =  $business_closed->format('U');

	// Start of Business Day
	$start_hour = date('G', strtotime($day_start));
	$start_minute = date('i', strtotime($day_start));
	$start_time = ($start_hour * 3600) + ($start_minute * 60);

	// End of Business Day
	$end_hour = date('G', strtotime($day_end));
	$end_minute = date('i', strtotime($day_end));
	$end_time = ($end_hour * 3600) + ($end_minute * 60);

}


function tslot_appt_totals(){

	global $wpdb,
	$ts_services_table,
	$start_time,
	$end_time,
	$appt_duration,
	$num_appts,
	$chosen_service,
	$visible_i18n;

	$service_info = 
	$wpdb->get_row(
	$wpdb->prepare(
		"SELECT 
		duration, before_service 
		FROM {$ts_services_table} 
		WHERE visibility = %s 
		AND service_title = %s", 
		$visible_i18n, $chosen_service
	));

	$service_before = $service_info -> before_service;
	$service_duration = $service_info -> duration;

	$appt_duration = $service_duration + $service_before;

	if ($end_time == 0 || $start_time == 0){
		return $num_appts = 0;
	}

	$num_appts = floor(($end_time - $start_time + $service_before) / ($service_duration + $service_before));

}


function tslot_after_close_today($weekday){

	global $timezone,
	$business_closed_unix,
	$to_datepicker;

	$now = new DateTime('now', new DateTimeZone($timezone));
	$today = $now->format('Y-m-d');
	$current_time = $now->format('U');
	$current_day_name = $now->format('l');

	if ($current_time > $business_closed_unix && $current_day_name === $weekday){
		if (!in_array($today, $to_datepicker)){
			$to_datepicker[]= $today;
		}
	}
}


function tslot_cutoff_date($weekday){

	// Cutoff date from minimum time before booking
	global $business_closed_unix,
	$timezone,
	$to_datepicker;

	$general_wp_option = get_option('timeslot-general-tab');

	if (!isset($general_wp_option['default-before-booking']['sec'])){
		return;
	}

	$before_booking_sec = $general_wp_option['default-before-booking']['sec'];
	$before_booking_ms = $before_booking_sec * 1000;
	$start_now = new DateTime('now', new DateTimeZone($timezone));
	$end_date = new DateTime('now', new DateTimeZone($timezone));
	$booking_cutoff = $end_date->modify('+ '.$before_booking_ms.' milliseconds +1 minute');
	$booking_cutoff_unix =  $booking_cutoff->format('U');
	$plus_one_day = new DateInterval('P1D');
	$cutoff_date_range = new DatePeriod($start_now, $plus_one_day , $booking_cutoff);

	// Get all dates between now and cutoff date
	foreach($cutoff_date_range as $date){

		$before_date = $date->format('Y-m-d');
		$before_day = $date->format('l');

		if ($booking_cutoff_unix < $business_closed_unix){
			continue;
		}
		if ($before_day !== $weekday){
			continue;
		}
		if (!in_array($before_date, $to_datepicker)){
			$to_datepicker[]= $before_date;
		}

	}
}


function tslot_staff_booked_for_service($weekday){

	global $wpdb,
	$ts_appt_table,
	$num_appts,
	$to_datepicker,
	$chosen_service,
	$chosen_staff,
	$approved_i18n;

	$get_appts_by_staff_and_service =
		$wpdb->get_results(
		$wpdb->prepare(
			"SELECT DATE(start_appt) as booked 
			FROM {$ts_appt_table}
			WHERE service_title = %s
			AND staff = %s
			AND start_appt >= NOW()
			AND DAYNAME(start_appt) = %s
			AND appt_status = %s
			GROUP BY DATE(start_appt)
			HAVING COUNT(start_appt) >= %d",
			$chosen_service, $chosen_staff, $weekday, $approved_i18n, $num_appts
	));

	foreach($get_appts_by_staff_and_service as $appt_date){

		if (!in_array($appt_date->booked, $to_datepicker)){
			$to_datepicker[]= $appt_date->booked;
		}

	}

}


function tslot_service_fully_booked($weekday){

	global $wpdb,
	$ts_appt_table,
	$ts_staff_services_table,
	$num_appts,
	$to_datepicker,
	$chosen_service,
	$approved_i18n;

	$num_appts_available = 
		$wpdb->get_var(
		$wpdb->prepare(
			"SELECT
			COUNT(service_title) * %d as available_count
			FROM {$ts_staff_services_table}
			WHERE service_title = %s", 
			$num_appts, $chosen_service
	));

	$get_appts_by_service = 
	$wpdb->get_results(
	$wpdb->prepare(
		"SELECT
		DATE(start_appt) as appt_date,
		COUNT(start_appt) as appt_count
		FROM {$ts_appt_table}
		WHERE service_title = %s
		AND start_appt >= NOW()
		AND DAYNAME(start_appt) = %s
		AND appt_status = %s
		GROUP BY start_appt , service_title
		HAVING COUNT(start_appt) > 1
		AND COUNT(service_title) > 1", 
		$chosen_service, $weekday, $approved_i18n
	));

	foreach($get_appts_by_service as $staff_booked){

		$appt_count = $staff_booked->appt_count;
		$appt_date = $staff_booked->appt_date;

		if ($appt_count < $num_appts_available){
			continue;
		}
		if (!in_array($appt_date, $to_datepicker)){
			$to_datepicker[]= $appt_date;
		}

	}

}


function tslot_fifteen_minute_intervals($weekday){

	global $wpdb,
	$ts_services_table,
	$ts_appt_table,
	$start_time,
	$appt_duration,
	$num_appts,
	$to_datepicker,
	$chosen_staff,
	$approved_i18n;

	$booked_dates_and_times = array();
	$booked_times = array();
	$appt_time_slots = array();

	$get_appts_by_staff = 
		$wpdb->get_results(
		$wpdb->prepare(
			"SELECT
			TIME({$ts_appt_table}.start_appt) as start_time,
			DATE({$ts_appt_table}.start_appt) as start_date,
			{$ts_services_table}.duration as duration,
			{$ts_services_table}.before_service as before_service
			FROM {$ts_appt_table}, {$ts_services_table}
			WHERE {$ts_appt_table}.start_appt >= NOW()
			AND DAYNAME({$ts_appt_table}.start_appt) = %s
			AND {$ts_appt_table}.service_title = {$ts_services_table}.service_title
			AND {$ts_appt_table}.appt_status = %s
			AND {$ts_appt_table}.staff = %s",
			$weekday, $approved_i18n, $chosen_staff
	));

	$service_time_slot = new DateTime("@$start_time");
	$appt_duration_interval = new DateInterval('PT'. $appt_duration . 'S');

	// Create all available time slots for selected service
	for($i=0; $i < $num_appts; $i++ ){

		$appt_time_slots[] = $service_time_slot->format('H:i:s');
		$service_time_slot->add( $appt_duration_interval );

	}

	//Create 15 minute booked time slots for each appoinment
	foreach($get_appts_by_staff as $appt){

		$appt_date = date('Y-m-d', strtotime($appt->start_date));
		$duration = (($appt->duration + $appt->before_service) / 60) / 15;
		$booked_interval = new DateTime($appt->start_time);
		$fifteen = new DateInterval('PT15M');

		for($i=0; $i < $duration; $i++ ){

			$booked_interval_format = $booked_interval->format('H:i:s');

			if (!in_array($booked_interval_format, $booked_times)){
				$booked_times[]= $booked_interval_format;
			}

			$booked_interval->add( $fifteen );

		}

		$booked_dates_and_times[]= array($appt_date => $booked_times);

		// Clear array for next appointment date
		$booked_times = array();

	}

	$booked_dates_and_times = array_merge_recursive(...$booked_dates_and_times);

	// Check if available times are in array of unavailable times
	foreach($booked_dates_and_times as $date => $times){

		$available_in_booked = array_diff($appt_time_slots, $times);

		if (!$available_in_booked){
			$to_datepicker[]= $date;
		}

	}
}